@@ -40,7 +40,7 @@ params = AttrDict(
 
     # Data params
     sample_rate=22050,
-    hop_samples=300,
+    hop_samples=300,  # Don't change this. Really.
     crop_mel_frames=24,
 
     # Model params
